from py_viptela.api.realtime import aaa
from py_viptela.api.realtime import apphosting
from py_viptela.api.realtime import applogs
from py_viptela.api.realtime import appqoe
from py_viptela.api.realtime import arp
from py_viptela.api.realtime import awareroute
from py_viptela.api.realtime import bfd
from py_viptela.api.realtime import bgp
from py_viptela.api.realtime import bridge
from py_viptela.api.realtime import cellular
from py_viptela.api.realtime import cellular
from py_viptela.api.realtime import cfm
from py_viptela.api.realtime import cloudexpress
from py_viptela.api.realtime import container
from py_viptela.api.realtime import crashlog
from py_viptela.api.realtime import devControl
from py_viptela.api.realtime import devFeature
from py_viptela.api.realtime import device
from py_viptela.api.realtime import devSystem
from py_viptela.api.realtime import dhcp
from py_viptela.api.realtime import dot1x
from py_viptela.api.realtime import dpi
from py_viptela.api.realtime import dre
from py_viptela.api.realtime import eigrp
from py_viptela.api.realtime import endpointtracker
from py_viptela.api.realtime import hardware
from py_viptela.api.realtime import igmp
from py_viptela.api.realtime import interface
from py_viptela.api.realtime import ip
from py_viptela.api.realtime import ipsec
from py_viptela.api.realtime import ipv6neighbours
from py_viptela.api.realtime import license
from py_viptela.api.realtime import multicast
from py_viptela.api.realtime import networkhub
from py_viptela.api.realtime import nms
from py_viptela.api.realtime import ntp
from py_viptela.api.realtime import omp
from py_viptela.api.realtime import ondemandLocal
from py_viptela.api.realtime import ondemandRemote
from py_viptela.api.realtime import orchestrator
from py_viptela.api.realtime import ospf
from py_viptela.api.realtime import pim
from py_viptela.api.realtime import policer
from py_viptela.api.realtime import policy
from py_viptela.api.realtime import pppoe
from py_viptela.api.realtime import rbac
from py_viptela.api.realtime import reboothistory
from py_viptela.api.realtime import sdwanstats
from py_viptela.api.realtime import security
from py_viptela.api.realtime import sfp
from py_viptela.api.realtime import sig
from py_viptela.api.realtime import software
from py_viptela.api.realtime import sslproxy
from py_viptela.api.realtime import system
from py_viptela.api.realtime import tcpopt
from py_viptela.api.realtime import tcpproxy
from py_viptela.api.realtime import transport
from py_viptela.api.realtime import trustsec
from py_viptela.api.realtime import tunnel
from py_viptela.api.realtime import ucse
from py_viptela.api.realtime import umbrella
from py_viptela.api.realtime import utd
from py_viptela.api.realtime import vdslservice
from py_viptela.api.realtime import vm
from py_viptela.api.realtime import voice
from py_viptela.api.realtime import vpn
from py_viptela.api.realtime import vrrp
from py_viptela.api.realtime import wireless
from py_viptela.api.realtime import wlan


def getDetail(vmanage, clusterName):
    """
    Get details of all existing Clusters
    
    Parameters:
    clusterName	 (string):	Cluster name
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/colocation/cluster?clusterName={clusterName}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def update(vmanage, clusterconfig):
    """
    Update a existing cluster
    
    Parameters:
    clusterconfig:	Cluster config
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/colocation/cluster"
    response = vmanage.apiCall("PUT", endpoint, clusterconfig)
    return response

def create(vmanage, clusterconfig):
    """
    Add a new cluster
    
    Parameters:
    clusterconfig:	Cluster config
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/colocation/cluster"
    response = vmanage.apiCall("POST", endpoint, clusterconfig)
    return response

def acitvate(vmanage, clusterName):
    """
    Activate a cluster
    
    Parameters:
    clusterName	 (string):	Cluster name
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/colocation/cluster/activate?clusterName={clusterName}"
    response = vmanage.apiCall("POST", endpoint)
    return response

def dummyccm(vmanage, clusterName):
    """
    Activate dummp cluster
    
    Parameters:
    clusterName	 (string):	Cluster name
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/colocation/cluster/activateClusterDummy?clusterName={clusterName}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def dummycspState(vmanage, clusterName, state):
    """
    Activate cluster in a state
    
    Parameters:
    clusterName	 (string):	Cluster name
	state	 (string):	Cluster state
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/colocation/cluster/activateClusterDummyState?clusterName={clusterName}&state={state}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def updateCspToCluster(vmanage, cspconfig):
    """
    Update attached csp to cluster
    
    Parameters:
    cspconfig:	CSP config
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/colocation/cluster/attached/csp"
    response = vmanage.apiCall("PUT", endpoint, cspconfig)
    return response

def preview(vmanage, serialNumber):
    """
    Clouddock cluster preview
    
    Parameters:
    serialNumber	 (string):	Serial number
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/colocation/cluster/config?serialNumber={serialNumber}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def deAcitvate(vmanage, clusterId):
    """
    Deactivate clouddock cluster
    
    Parameters:
    clusterId	 (string):	Cluster Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/colocation/cluster/deactivate?clusterId={clusterId}"
    response = vmanage.apiCall("POST", endpoint)
    return response

def getDetailById(vmanage, clusterId):
    """
    Get cluster by Id
    
    Parameters:
    clusterId	 (string):	Cluster Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/colocation/cluster/id?clusterId={clusterId}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def rmaCloudDockCsp(vmanage, bodyParameter, clusterName):
    """
    RMA operation for CSP device
    
    Parameters:
    bodyParameter:	Description
	clusterName	 (string):	Cluster name
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/colocation/cluster/rma?clusterName={clusterName}"
    response = vmanage.apiCall("POST", endpoint, bodyParameter)
    return response

def deleteByName(vmanage, clustername):
    """
    Delete cluster by name
    
    Parameters:
    clustername	 (string):	Cluster name
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/colocation/cluster/{clustername}"
    response = vmanage.apiCall("DELETE", endpoint)
    return response



from py_viptela.api.config.assembler import security
from py_viptela.api.config.assembler import vedge
from py_viptela.api.config.assembler import voice
from py_viptela.api.config.assembler import vsmart


def sleauthenticate(vmanage, partner):
    """
    authenticate user for sle
    
    Parameters:
    partner:	Partner
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/smartLicensing/authenticate"
    response = vmanage.apiCall("POST", endpoint, partner)
    return response
def fetchAccounts(vmanage, partner, mode):
    """
    fetch sava for sle
    
    Parameters:
    partner:	Partner
	mode	 (string):	mode
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/smartLicensing/fetchAccounts?mode={mode}"
    response = vmanage.apiCall("GET", endpoint, partner)
    return response
def fetchReports(vmanage, partner):
    """
    fetch reports offline for sle
    
    Parameters:
    partner:	Partner
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/smartLicensing/fetchAllSa"
    response = vmanage.apiCall("GET", endpoint, partner)
    return response
def fetchReports(vmanage, partner, saDomain, saId):
    """
    fetch reports offline for sle
    
    Parameters:
    partner:	Partner
	saDomain	 (string):	saDomain
	saId	 (string):	saId
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/smartLicensing/fetchReportsForSa?saDomain={saDomain}&saId={saId}"
    response = vmanage.apiCall("GET", endpoint, partner)
    return response
def getUserSettings(vmanage):
    """
    get settings
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/smartLicensing/getUserSettings"
    response = vmanage.apiCall("GET", endpoint)
    return response
def syncLicenses(vmanage, partner):
    """
    get all licenses for sa/va
    
    Parameters:
    partner:	Partner
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/smartLicensing/removeSaVaSelection"
    response = vmanage.apiCall("POST", endpoint, partner)
    return response
def syncLicenses(vmanage, partner):
    """
    get all licenses for sa/va
    
    Parameters:
    partner:	Partner
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/smartLicensing/syncLicenses"
    response = vmanage.apiCall("POST", endpoint, partner)
    return response
def uploadAck(vmanage, partner):
    """
    upload ack file  for sa/va
    
    Parameters:
    partner:	Partner
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/smartLicensing/uploadAck"
    response = vmanage.apiCall("POST", endpoint, partner)
    return response



def getHistoryList(vmanage, systemIp, color, deviceId):
    """
    Get BFD session history from device (Real Time)
    
    Parameters:
    systemIp	    (string):	System IP
	color	        (string):	Remote color
	deviceId	    (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/bfd/history?system-ip={systemIp}&color={color}&deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getLinkList(vmanage, state):
    """
    Get list of BFD connections
    
    Parameters:
    state	 (string):	Device state
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/bfd/links?state={state}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getSessions(vmanage, systemIp, color, localColor, deviceId):
    """
    Get list of BFD sessions from vManage (Real Time)
    
    Parameters:
    systemIp	    (string):	System IP
	color	        (string):	Remote color
	local-color	    (string):	Source color
	deviceId	    (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/bfd/sessions?system-ip={systemIp}&color={color}&local-color={localColor}&deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getSiteStateDetail(vmanage):
    """
    Get detailed BFD site details
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/bfd/sites/detail"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getSitesSummary(vmanage, isCached, vpnId):
    """
    Get BFD site summary
    
    Parameters:
    isCached	 (boolean):	Flag for caching
	vpnId	 (array):	Filter VPN
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/bfd/sites/summary?isCached={isCached}&vpnId={vpnId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getStateSummary(vmanage, deviceId):
    """
    Get device BFD state summary
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/bfd/state/device?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getStateSummaryTloc(vmanage, deviceId):
    """
    Get device BFD state summary with tloc color
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/bfd/state/device/tloc?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getStatus(vmanage):
    """
    Get device BFD status
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/bfd/status"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getSummary(vmanage, deviceId):
    """
    Get BFD summary from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/bfd/summary?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getStatusSummary(vmanage, deviceId):
    """
    Get device BFD status summary
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/bfd/summary/device?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getSyncSession(vmanage, systemIp, color, localColor, deviceId):
    """
    Get list of BFD sessions from vManage synchronously
    
    Parameters:
    systemIp	    (string):	System IP
	color	        (string):	Remote color
	localColor	    (string):	Source color
	deviceId	    (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/bfd/synced/sessions?system-ip={systemIp}&color={color}&local-color={localColor}&deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getTLOCSummary(vmanage, deviceId):
    """
    Get TLOC summary from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/bfd/tloc?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response



def getCertDetails(vmanage, parsecert):
    """
    Get cert details
    
    Parameters:
    parsecert:	parse cert
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/certificate/certdetails"
    response = vmanage.apiCall("POST", endpoint, parsecert)
    return response

def getCSRViewRightMenus(vmanage):
    """
    Get CSR detail view
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/certificate/csr/details"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getDeviceViewRightMenus(vmanage):
    """
    Get device detail view
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/certificate/device/details"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getDevicesList(vmanage):
    """
    Get vEdge list
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/certificate/device/list"
    response = vmanage.apiCall("GET", endpoint)
    return response

def forceSyncRootCert(vmanage, singedcertificate):
    """
    Force sync root certificate
    NOTE: In a multitenant vManage system, this API is only available in the Provider and Provider-As-Tenant view.
    
    Parameters:
    singedcertificate:	Singed certificate
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/certificate/forcesync/rootCert"
    response = vmanage.apiCall("POST", endpoint, singedcertificate)
    return response

def generateCSR(vmanage, csrRequest):
    """
    Generate CSR
    NOTE: In a multitenant vManage system, this API is only available in the Provider and Provider-As-Tenant view.
    
    Parameters:
    csrRequest:	CSR request for device
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/certificate/generate/csr"
    response = vmanage.apiCall("POST", endpoint, csrRequest)
    return response

def generateEntCSR(vmanage, csrRequest):
    """
    Generate CSR
    NOTE: In a multitenant vManage system, this API is only available in the Provider and Provider-As-Tenant view.
    
    Parameters:
    csrRequest:	CSR request for device
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/certificate/generate/enterprise/csr/vedge"
    response = vmanage.apiCall("POST", endpoint, csrRequest)
    return response

def generateVedgeEntCSR(vmanage, csrRequest):
    """
    Generate CSR
    NOTE: In a multitenant vManage system, this API is only available in the Provider and Provider-As-Tenant view.
    
    Parameters:
    csrRequest:	CSR request for device
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/certificate/generate/wanedge/csr"
    response = vmanage.apiCall("POST", endpoint, csrRequest)
    return response

def installCertificate(vmanage, singedCert):
    """
    Install singed certificate
    NOTE: In a multitenant vManage system, this API is only available in the Provider and Provider-As-Tenant view.
    
    Parameters:
    singedCert:	Singed certificate
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/certificate/install/signedCert"
    response = vmanage.apiCall("POST", endpoint, singedCert)
    return response

def updateJks(vmanage, updatejks):
    """
    update JKS
    NOTE: In a multitenant vManage system, this API is only available in the Provider and Provider-As-Tenant view.
    
    Parameters:
    updatejks:	Update JKS
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/certificate/jks"
    response = vmanage.apiCall("PUT", endpoint, updatejks)
    return response

def getListStatus(vmanage):
    """
    get certificate
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/certificate/list/status"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getCertificateData(vmanage):
    """
    Get certificate chain
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/certificate/record"
    response = vmanage.apiCall("GET", endpoint)
    return response

def resetRSA(vmanage, csrRequest):
    """
    Register CSR
    NOTE: In a multitenant vManage system, this API is only available in the Provider and Provider-As-Tenant view.
    
    Parameters:
    csrRequest:	CSR request for vEdge
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/certificate/reset/rsa"
    response = vmanage.apiCall("POST", endpoint, csrRequest)
    return response

def decommissionEnterpriseCSRForVedge(vmanage, revokingcsrforhardwarevedge):
    """
    Revoking enterprise CSR for hardware vEdge
    NOTE: In a multitenant vManage system, this API is only available in the Provider and Provider-As-Tenant view.
    
    Parameters:
    revokingcsrforhardwarevedge:	Revoking CSR for hardware vEdge
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/certificate/revoke/enterprise/certificate"
    response = vmanage.apiCall("POST", endpoint, revokingcsrforhardwarevedge)
    return response

def getRootCertChains(vmanage, action):
    """
    Get root cert chain
    
    Parameters:
    action	 (string):	Action
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/certificate/rootcertchains?action={action}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def saveRootCertChain(vmanage, rootChain):
    """
    Save root cert chain
    NOTE: In a multitenant vManage system, this API is only available in the Provider and Provider-As-Tenant view.
    
    Parameters:
    rootChain:	Save root cert chain
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/certificate/rootcertchains"
    response = vmanage.apiCall("PUT", endpoint, rootChain)
    return response

def getRootCertificate(vmanage):
    """
    Get device root certificate detail view
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/certificate/rootcertificate"
    response = vmanage.apiCall("GET", endpoint)
    return response

def saveVEdgeList(vmanage, deviceList):
    """
    Save vEdge device list
    
    Parameters:
    deviceList:	vEdge device list
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/certificate/save/vedge/list"
    response = vmanage.apiCall("POST", endpoint, deviceList)
    return response

def getCertificateDetail(vmanage):
    """
    Get certificate detail
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/certificate/stats/detail"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getCertificateStats(vmanage):
    """
    Get certificate expiration status
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/certificate/stats/summary"
    response = vmanage.apiCall("GET", endpoint)
    return response

def syncvBond(vmanage):
    """
    sync vManage UUID to all vBond
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/certificate/syncvbond"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getcEdgeList(vmanage):
    """
    Get cEdge list with tokengenerated list
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/certificate/tokengeneratedlist"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getInstalledCert(vmanage):
    """
    Get Installed Certificate
    NOTE: In a multitenant vManage system, this API is only available in the Provider and Provider-As-Tenant view.
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/certificate/vedge"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getvEdgeCSR(vmanage):
    """
    Get vEdge CSR Certificate
    NOTE: In a multitenant vManage system, this API is only available in the Provider and Provider-As-Tenant view.
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/certificate/vedge/csr"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getvEdgeList(vmanage, model, state):
    """
    Get vEdge list
    
    Parameters:
    model	 (string):	Device model
	state	 (array):	Device state
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/certificate/vedge/list?model={model}&state={state}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def setvEdgeList(vmanage, deviceList):
    """
    Save vEdge list
    
    Parameters:
    deviceList:	vEdge device list
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/certificate/vedge/list"
    response = vmanage.apiCall("POST", endpoint, deviceList)
    return response

def getView(vmanage):
    """
    Get certificate UI view
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/certificate/view"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getvSmartList(vmanage):
    """
    Get vSmart list
    NOTE: In a multitenant vManage system, this API is only available in the Provider and Provider-As-Tenant view.
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/certificate/vsmart/list"
    response = vmanage.apiCall("GET", endpoint)
    return response

def setvSmartList(vmanage):
    """
    Save vSmart list
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/certificate/vsmart/list"
    response = vmanage.apiCall("POST", endpoint)
    return response

def deleteConfig(vmanage, uuid, replaceController, deviceId):
    """
    Invalidate device
    NOTE: In a multitenant vManage system, this API is only available in the Provider and Provider-As-Tenant view.
    
    Parameters:
    uuid	                (string):	Device uuid
	replaceController	    (boolean):	Replace a vSmart in Multi-tenant setup with a new vSmart
	deviceId	            (string):	uuid of new vSmart
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/certificate/{uuid}?replaceController={replaceController}&deviceId={deviceId}"
    response = vmanage.apiCall("DELETE", endpoint)
    return response



def getGroups(vmanage, deviceId):
    """
    Get IGMP neighbor list from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/igmp/groups?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getInterfaces(vmanage, deviceId):
    """
    Get IGMP interface list from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/igmp/interface?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getStats(vmanage, deviceId):
    """
    Get IGMP statistics list from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/igmp/statistics?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getSummary(vmanage, deviceId):
    """
    Get IGMP summary from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/igmp/summary?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response



def pushConfigs(vmanage, config, nmsId):
    """
    Push device configs
    
    Parameters:
    config:	            Netconf configuration
	nmsId	 (string):	NMS Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/partner/wcm/netconf/{nmsId}"
    response = vmanage.apiCall("POST", endpoint, config)
    return response



def getAllCloudAccounts(vmanage, cloudType, cgEnable):
    """
    Get All cloud accounts
    
    Parameters:
    cloudType	 (string):	Cloud type
	cgEnable	 (boolean):	Cloud gateway enabled flag
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/accounts?cloudType={cloudType}&cloudGatewayEnabled={cgEnable}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def validateAccountAdd(vmanage, account):
    """
    Authenticate cloud account credentials
    
    Parameters:
    account:	Multicloud account info
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/accounts"
    response = vmanage.apiCall("POST", endpoint, account)
    return response

def getEdgeAccounts(vmanage, edgeType):
    """
    Get all Multicloud edge accounts
    
    Parameters:
    edgeType	 (string):	Edge type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/accounts/edge?edgeType={edgeType}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def validateEdgeAccountAdd(vmanage, account):
    """
    Authenticate edge account credentials
    
    Parameters:
    account:	Multicloud edge account info
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/accounts/edge"
    response = vmanage.apiCall("POST", endpoint, account)
    return response

def getEdgeAccountDetails(vmanage, accountId):
    """
    Get edge account by account Id
    
    Parameters:
    accountId	 (string):	Edge Account Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/accounts/edge/{accountId}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def updateEdgeAccount(vmanage, account, accountId):
    """
    Update Multicloud edge account
    
    Parameters:
    account:	Multicloud edge account info
	accountId	 (string):	Multicloud Edge Account Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/accounts/edge/{accountId}"
    response = vmanage.apiCall("PUT", endpoint, account)
    return response

def deleteEdgeAccount(vmanage, accountId):
    """
    Delete edge account
    
    Parameters:
    accountId	 (string):	Edge Account Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/accounts/edge/{accountId}"
    response = vmanage.apiCall("DELETE", endpoint)
    return response

def validateEdgeAccountUpdateCred(vmanage, account, accountId):
    """
    Update Multicloud edge account credential
    
    Parameters:
    account:	Multicloud edge account info
	accountId	 (string):	Multicloud Edge Account Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/accounts/edge/{accountId}/credentials"
    response = vmanage.apiCall("PUT", endpoint, account)
    return response

def getCloudAccountDetails(vmanage, accountId):
    """
    Get cloud account by account Id
    
    Parameters:
    accountId	 (string):	Account Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/accounts/{accountId}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def updateAccount(vmanage, account, accountId):
    """
    Update multicloud account
    
    Parameters:
    account:	Multicloud account info
	accountId	 (string):	Account Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/accounts/{accountId}"
    response = vmanage.apiCall("PUT", endpoint, account)
    return response

def deleteAccount(vmanage, accountId):
    """
    Delete cloud account
    
    Parameters:
    accountId	 (string):	Account Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/accounts/{accountId}"
    response = vmanage.apiCall("DELETE", endpoint)
    return response

def validateAccountUpdateCred(vmanage, account, accountId):
    """
    Update multicloud account credential
    
    Parameters:
    account:	Multicloud account info
	accountId	 (string):	Account Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/accounts/{accountId}/credentials"
    response = vmanage.apiCall("PUT", endpoint, account)
    return response

def auditDryRun(vmanage, cloudType, cloudRegion):
    """
    Call an audit with dry run
    
    Parameters:
    cloudType	 (string):	Cloud type
	cloudRegion	 (string):	Region
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/audit?cloudType={cloudType}&cloudRegion={cloudRegion}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def audit(vmanage, audit):
    """
    Call an audit
    
    Parameters:
    audit:	Audit
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/audit"
    response = vmanage.apiCall("POST", endpoint, audit)
    return response

def getEdgeBillingAccounts(vmanage, edgeType, edgeAccountId, region):
    """
    Get Edge Billing Accounts
    
    Parameters:
    edgeType	 (string):	Interconnect Provider
	edgeAccountId	 (string):	Interconnect Provider Account ID
	region	 (string):	Region
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/billingaccounts/edge/{edgeType}/{edgeAccountId}?region={region}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getCgws(vmanage, cloudType, accountId, region, cgName):
    """
    Get cloud gateways
    
    Parameters:
    cloudType	 (string):	Cloud type
	accountId	 (string):	Account Id
	region	 (string):	Region
	cgName	 (string):	Cloud gateway name
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/cloudgateway?cloudType={cloudType}&accountId={accountId}&region={region}&cloudGatewayName={cgName}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def createCgw(vmanage, cg):
    """
    Create cloud gateway
    
    Parameters:
    cg:	Cloud gateway
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/cloudgateway"
    response = vmanage.apiCall("POST", endpoint, cg)
    return response

def getAzureNetworkVirtualAppliances(vmanage, cloudType, accoundId, region, rgName, rgSource, vhubName, vhubSource):
    """
    Discover Azure Virtual NVAs
    
    Parameters:
    cloudType	 (string):	Cloud type
	accoundId	 (string):	Account ID
	region	 (string):	Region
	rgName	 (string):	Resource Group Name
	rgSource	 (string):	Resource Group Source
	vhubName	 (string):	VHUB name
	vhubSource	 (string):	VHUB source
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/cloudgateway/nvas?cloudType={cloudType}&accoundId={accoundId}&region={region}&resourceGroupName={rgName}&resourceGroupSource={rgSource}&vhubName={vhubName}&vhubSource={vhubSource}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getAzureNvaSkuList(vmanage):
    """
    Get Azure NVA SKUs
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/cloudgateway/nvasku"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getCgwOrgResources(vmanage, cgName):
    """
    Get cloud gateways
    
    Parameters:
    cgName	 (string):	Cloud gateway name
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/cloudgateway/resource?cloudGatewayName={cgName}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getAzureResourceGroups(vmanage, cloudType, accountId):
    """
    Discover Azure Resource Groups
    
    Parameters:
    cloudType	 (string):	Cloud type
	accountId	 (string):	Account ID
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/cloudgateway/resourceGroups?cloudType={cloudType}&accountId={accountId}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getAzureVirtualHubs(vmanage, cloudType, accoundId, region, rgName, rgSource, vwanName, vwanSource):
    """
    Discover Azure Virtual HUBs
    
    Parameters:
    cloudType	 (string):	Cloud type
	accoundId	 (string):	Account ID
	region	 (string):	Region
	rgName	 (string):	Resource Group Name
	rgSource	 (string):	Resource Group Source
	vwanName	 (string):	VWAN name
	vwanSource	 (string):	VWAN source
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/cloudgateway/vhubs?cloudType={cloudType}&accoundId={accoundId}&region={region}&resourceGroupName={rgName}&resourceGroupSource={rgSource}&vwanName={vwanName}&vwanSource={vwanSource}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getAzureVirtualWans(vmanage, cloudType, accoundId, rgName, rgSource):
    """
    Discover Azure Virtual WANs
    
    Parameters:
    cloudType	 (string):	Cloud type
	accoundId	 (string):	Account ID
	rgName	 (string):	Resource Group Name
	rgSource	 (string):	Resource Group Source
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/cloudgateway/vwans?cloudType={cloudType}&accoundId={accoundId}&resourceGroupName={rgName}&resourceGroupSource={rgSource}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getCgwDetails(vmanage, cgName):
    """
    Get cloud gateway by name
    
    Parameters:
    cgName	 (string):	Cloud gateway name
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/cloudgateway/{cgName}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def updateCgw(vmanage, cloudgateway, cgName):
    """
    Update cloud gateway
    
    Parameters:
    cloudgateway:	Cloud gateway
	cgName	 (string):	Cloud gateway name
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/cloudgateway/{cgName}"
    response = vmanage.apiCall("PUT", endpoint, cloudgateway)
    return response

def deleteCgw(vmanage, cgName):
    """
    Delete cloud gateway
    
    Parameters:
    cgName	 (string):	Cloud gateway name
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/cloudgateway/{cgName}"
    response = vmanage.apiCall("DELETE", endpoint)
    return response

def getSitesAttached(vmanage, cgName, systemIp, siteId, color, vpnTunnelStatus):
    """
    Get sites attached to CGW
    
    Parameters:
    cgName	 (string):	Cloud gateway name
	systemIp	 (string):	System IP
	siteId	 (string):	Site Id
	color	 (string):	Color
	vpnTunnelStatus	 (boolean):	Fetch vpnTunnelStatus
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/cloudgateway/{cgName}/site?systemIp={systemIp}&siteId={siteId}&color={color}&vpnTunnelStatus={vpnTunnelStatus}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def TunnelScaling(vmanage, siteinformation, cgName):
    """
    Update tunnel scaling and accelerated vpn parameter for a branch endpoint
    
    Parameters:
    siteinformation:	Site information
	cgName	 (string):	Cloud gateway name
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/cloudgateway/{cgName}/site"
    response = vmanage.apiCall("PUT", endpoint, siteinformation)
    return response

def attachSites(vmanage, siteinformation, cgName):
    """
    Attach sites to cloud gateway
    
    Parameters:
    siteinformation:	Site information
	cgName	 (string):	Cloud gateway name
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/cloudgateway/{cgName}/site"
    response = vmanage.apiCall("POST", endpoint, siteinformation)
    return response

def detachSites(vmanage, siteinformation, cgName):
    """
    Detach sites from cloud gateway
    
    Parameters:
    siteinformation:	Site information
	cgName	 (string):	Cloud gateway name
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/cloudgateway/{cgName}/site"
    response = vmanage.apiCall("DELETE", endpoint, siteinformation)
    return response

def getCloudGateways(vmanage, cloudType):
    """
    Get sites with connectivity to the cloud by cloud type
    
    Parameters:
    cloudType	 (string):	Cloud type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/cloudgateways/{cloudType}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getCgwCustomSettingDetails(vmanage, cgName):
    """
    Get cloud gateway custom setting by cloud gateway name
    
    Parameters:
    cgName	 (string):	Cloud gateway name
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/cloudgatewaysetting/{cgName}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getCgwTypes(vmanage, cloudType):
    """
    Get cloud gateway types for specified cloudType
    
    Parameters:
    cloudType	 (string):	Cloud type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/cloudgatewaytype?cloudType={cloudType}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getCloudConnectedSitesByEdgeType(vmanage, edgeType, edgeGatewayName):
    """
    Get sites with connectivity to the interconnect gateways by edge type
    
    Parameters:
    edgeType	 (string):	Edge type
	edgeGatewayName	 (string):	Interconnect Gateway Name
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/connected-sites/edge/{edgeType}?edgeGatewayName={edgeGatewayName}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getCloudConnectedSitesByCloudType(vmanage, cloudType, cgName):
    """
    Get sites with connectivity to the cloud by cloud type
    
    Parameters:
    cloudType	 (string):	Cloud type
	cgName	 (string):	Cloud Gateway Name
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/connected-sites/{cloudType}?cloudGatewayName={cgName}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getEdgeConnectivityDetails(vmanage, edgeType, connectivityName, connectivityType, edgeGatewayName):
    """
    Get Interconnect Connectivity details
    
    Parameters:
    edgeType	 (string):	Edge type
	connectivityName	 (string):	Connectivity Name
	connectivityType	 (string):	Connectivity Type
	edgeGatewayName	 (string):	Interconnect Gateway name
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/connectivity/edge?edgeType={edgeType}&connectivityName={connectivityName}&connectivityType={connectivityType}&edgeGatewayName={edgeGatewayName}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def updateEdgeConnectivity(vmanage, edgeconnectivity):
    """
    Update Interconnect connectivity
    
    Parameters:
    edgeconnectivity:	Edge connectivity
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/connectivity/edge"
    response = vmanage.apiCall("PUT", endpoint, edgeconnectivity)
    return response

def createEdgeConnectivity(vmanage, edgeconnectivity):
    """
    Create Interconnect connectivity
    
    Parameters:
    edgeconnectivity:	Edge connectivity
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/connectivity/edge"
    response = vmanage.apiCall("POST", endpoint, edgeconnectivity)
    return response

def deleteEdgeConnectivity(vmanage, connectionName):
    """
    Delete Interconnect connectivity
    
    Parameters:
    connectionName	 (string):	Edge connectivity name
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/connectivity/edge/{connectionName}"
    response = vmanage.apiCall("DELETE", endpoint)
    return response

def getEdgeConnectivityDetailByName(vmanage, connectivityName):
    """
    Get Interconnect Connectivity by name
    
    Parameters:
    connectivityName	 (string):	IC-GW connectivity name
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/connectivity/edge/{connectivityName}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getConnectivityGateways(vmanage, accountId, cloudType, connectivityType, connectivityGatewayName, region, network, state, refresh):
    """
    Get all Connectivity Gateways
    
    Parameters:
    accountId	 (string):	Account Id
	cloudType	 (string):	Cloud Type
	connectivityType	 (string):	Cloud Connectivity Type
	connectivityGatewayName	 (string):	Connectivity Gateway Name
	region	 (string):	Region
	network	 (string):	Network
	state	 (string):	State
	refresh	 (string):	Refresh
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/connectivitygateway?accountId={accountId}&cloudType={cloudType}&connectivityType={connectivityType}&connectivityGatewayName={connectivityGatewayName}&region={region}&network={network}&state={state}&refresh={refresh}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def createConnectivityGateway(vmanage, connectivitygateway):
    """
    Create Connectivity gateway
    
    Parameters:
    connectivitygateway:	Connectivity gateway
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/connectivitygateway"
    response = vmanage.apiCall("POST", endpoint, connectivitygateway)
    return response

def cleanUpAllConnectivityGatewaysInLocalDB(vmanage, deletionType):
    """
    Delete all Connectivity Gateways in local DB
    
    Parameters:
    deletionType	 (string):	Deletion Type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/connectivitygateway?deletionType={deletionType}"
    response = vmanage.apiCall("DELETE", endpoint)
    return response

def deleteConnectivityGateway(vmanage, cloudProvider, connectivityGatewayName, connectivityType):
    """
    Delete Connectivity Gateway
    
    Parameters:
    cloudProvider	 (string):	Cloud Provider
	connectivityGatewayName	 (string):	Connectivity gateway name
	connectivityType	 (string):	Cloud Connectivity Type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/connectivitygateway/{cloudProvider}/{connectivityGatewayName}?connectivityType={connectivityType}"
    response = vmanage.apiCall("DELETE", endpoint)
    return response

def getConnectivityGatewayCreationOptions(vmanage, accountId, cloudType, connectivityType, refresh):
    """
    Get connectivity gateway creation options
    
    Parameters:
    accountId	 (string):	Account Id
	cloudType	 (string):	Cloud Type
	connectivityType	 (string):	Cloud Connectivity Type
	refresh	 (string):	Refresh
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/connectivitygatewaycreationoptions?accountId={accountId}&cloudType={cloudType}&connectivityType={connectivityType}&refresh={refresh}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getDashboardEdgeInfo(vmanage):
    """
    Get interconnect edge gateway dashboard info
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/dashboard/edge"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getWanDevices(vmanage):
    """
    Get available WAN edge devices
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/device"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getCloudDevicesByEdgeType(vmanage, edgeType, edgeGatewayName):
    """
    Get cloud devices by edge type
    
    Parameters:
    edgeType	 (string):	Edge type
	edgeGatewayName	 (string):	Edge Gateway Name
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/devices/edge/{edgeType}?edgeGatewayName={edgeGatewayName}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getCloudDevicesCloudType(vmanage, cloudType, cgName):
    """
    Get cloud devices by cloud type
    
    Parameters:
    cloudType	 (string):	Cloud type
	cgName	 (string):	Cloud Gateway Name
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/devices/{cloudType}?cloudGatewayName={cgName}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getEdgeWanDevices(vmanage, edgeType):
    """
    Get available WAN edge devices
    
    Parameters:
    edgeType	 (string):	Edge Type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/edge/{edgeType}/device"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getIcgws(vmanage, edgeType, accountId, region, regionId, resourceState, edgeGatewayName):
    """
    Get Interconnect Gateways
    
    Parameters:
    edgeType	 (string):	Edge type
	accountId	 (string):	Account Id
	region	 (string):	Region
	regionId	 (string):	Region Id
	resourceState	 (string):	Resource State
	edgeGatewayName	 (string):	Edge gateway name
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/gateway/edge?edgeType={edgeType}&accountId={accountId}&region={region}&regionId={regionId}&resourceState={resourceState}&edgeGatewayName={edgeGatewayName}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def createIcgw(vmanage, interconnectgateway):
    """
    Create Interconnect Gateway
    
    Parameters:
    interconnectgateway:	Interconnect Gateway
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/gateway/edge"
    response = vmanage.apiCall("POST", endpoint, interconnectgateway)
    return response

def getIcgwCustomSettingDetails(vmanage, edgeGatewayName):
    """
    Get Interconnect Gateway custom setting by Interconnect Gateway name
    
    Parameters:
    edgeGatewayName	 (string):	Edge gateway name
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/gateway/edge/setting/{edgeGatewayName}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getIcgwTypes(vmanage, edgeType):
    """
    Get Interconnect Gateway type for specified Edge Provider
    
    Parameters:
    edgeType	 (string):	Edge type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/gateway/edge/types?edgeType={edgeType}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getIcgwDetails(vmanage, edgeGatewayName):
    """
    Get Interconnect Gateway by name
    
    Parameters:
    edgeGatewayName	 (string):	Edge gateway name
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/gateway/edge/{edgeGatewayName}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def updateIcgw(vmanage, gatewayInfo, edgeGatewayName):
    """
    Update Interconnect Gateway
    
    Parameters:
    gatewayInfo:	Description
	edgeGatewayName	 (string):	Edge gateway name
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/gateway/edge/{edgeGatewayName}"
    response = vmanage.apiCall("PUT", endpoint, gatewayInfo)
    return response

def deleteIcgw(vmanage, edgeGatewayName):
    """
    Delete Interconnect Gateway
    
    Parameters:
    edgeGatewayName	 (string):	Edge gateway name
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/gateway/edge/{edgeGatewayName}"
    response = vmanage.apiCall("DELETE", endpoint)
    return response

def getEdgeGateways(vmanage, edgeType):
    """
    Get sites with connectivity to the interconnect gateways by edge type
    
    Parameters:
    edgeType	 (string):	Edge type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/gateways/edge/{edgeType}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getHostVpcs(vmanage, cloudType, accountIds, region, untagged):
    """
    Get tagged, untagged, or all Host VPCs
    
    Parameters:
    cloudType	 (string):	Cloud type
	accountIds	 (string):	Account Id
	region	 (string):	Region
	untagged	 (string):	Untagged flag
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/hostvpc?cloudType={cloudType}&accountIds={accountIds}&region={region}&untagged={untagged}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getVpcTags(vmanage, cloudType, region, tagName):
    """
    Get vpc tags
    
    Parameters:
    cloudType	 (string):	Cloud type
	region	 (string):	Region
	tagName	 (string):	Tag name
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/hostvpc/tags?cloudType={cloudType}&region={region}&tagName={tagName}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def editTag(vmanage, vpctag):
    """
    Edit VPCs for a tag
    
    Parameters:
    vpctag:	VPC tag
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/hostvpc/tags"
    response = vmanage.apiCall("PUT", endpoint, vpctag)
    return response

def hostvpcTagging(vmanage, vpctag):
    """
    Tag a VPC
    
    Parameters:
    vpctag:	VPC tag
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/hostvpc/tags"
    response = vmanage.apiCall("POST", endpoint, vpctag)
    return response

def unTag(vmanage, tagName):
    """
    Delete a tag
    
    Parameters:
    tagName	 (string):	Tag name
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/hostvpc/tags/{tagName}"
    response = vmanage.apiCall("DELETE", endpoint)
    return response

def getSupportedEdgeImageNames(vmanage, edgeType):
    """
    Get Edge provider supported images
    
    Parameters:
    edgeType	 (string):	Edge type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/imagename/edge?edgeType={edgeType}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getSupportedInstanceSize(vmanage, cloudType, accountId, cloudRegion):
    """
    Get Transit VPC supported size
    
    Parameters:
    Parameter Description
	Parameter Description
	Parameter Description
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/instancesize?cloudType={cloudType}&accountId={accountId}&cloudRegion={cloudRegion}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getSupportedEdgeInstanceSize(vmanage, edgeType):
    """
    Get Edge provider supported size
    
    Parameters:
    edgeType	 (string):	Edge type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/instancesize/edge?edgeType={edgeType}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getWanInterfaceColors(vmanage):
    """
    Get WAN interface colors
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/interfacecolor"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getEdgeLocationsInfo(vmanage, edgeType, accountId, region):
    """
    Get Edge Locations
    
    Parameters:
    edgeType	 (string):	Edge Type
	accountId	 (string):	Edge Account Id
	region	 (string):	Region
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/locations/edge/{edgeType}?accountId={accountId}&region={region}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def deleteEdge(vmanage, edgeType):
    """
    Delete edge
    
    Parameters:
    edgeType	 (string):	Edge Type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/locations/edge/{edgeType}"
    response = vmanage.apiCall("DELETE", endpoint)
    return response

def updateEdgeLocationsInfo(vmanage, edgeType, accountId):
    """
    Update Edge Locations
    
    Parameters:
    edgeType	 (string):	Edge Type
	accountId	 (string):	Edge Account Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/locations/edge/{edgeType}/accountId/{accountId}"
    response = vmanage.apiCall("PUT", endpoint)
    return response

def getMappingMatrix(vmanage, cloudType):
    """
    Get default mapping values
    
    Parameters:
    cloudType	 (string):	Cloud type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/map?cloudType={cloudType}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def processMapping(vmanage, vpcmapping):
    """
    Process intent of connecting VPNs with VPCs through cloud gateway
    
    Parameters:
    vpcmapping:	VPC mapping
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/map"
    response = vmanage.apiCall("POST", endpoint, vpcmapping)
    return response

def getDefaultMappingValues(vmanage, cloudType):
    """
    Get default mapping values
    
    Parameters:
    cloudType	 (string):	Cloud type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/map/defaults?cloudType={cloudType}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getMappingStatus(vmanage, cloudType, region):
    """
    Get mapping status
    
    Parameters:
    cloudType	 (string):	Cloud type
	region	 (string):	Region
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/map/status?cloudType={cloudType}&region={region}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getMappingSummary(vmanage, vpnTunnelStatus, cloudType):
    """
    Get mapping summary
    
    Parameters:
    vpnTunnelStatus	 (boolean):	VPN tunnel status
	cloudType	 (string):	Cloud type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/map/summary?vpnTunnelStatus={vpnTunnelStatus}&cloudType={cloudType}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getMappingTags(vmanage, cloudType):
    """
    Get default mapping values
    
    Parameters:
    cloudType	 (string):	Cloud type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/map/tags?cloudType={cloudType}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getEdgeMappingTags(vmanage, cloudType, accountId):
    """
    Get default Interconnect mapping tag values
    
    Parameters:
    cloudType	 (string):	Cloud type
	accountId	 (string):	Cloud Account Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/map/tags/edge?cloudType={cloudType}&accountId={accountId}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getMappingVpns(vmanage):
    """
    Get default mapping values
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/map/vpns"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getCgwAssociatedMappings(vmanage, cloudType, cgName, siteUuid):
    """
    Get associated mappings to the CGW
    
    Parameters:
    cloudType	 (string):	Cloud type
	cgName	 (string):	Cloud Gateway Name
	siteUuid	 (string):	Site Device UUID
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/mapping/{cloudType}?cloudGatewayName={cgName}&siteUuid={siteUuid}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getPartnerPorts(vmanage, edgeType, accountId, cloudType, connectType, vxcPermitted, authorizationKey, refresh):
    """
    Get partner ports
    
    Parameters:
    edgeType	 (string):	Edge type
	accountId	 (string):	Edge Account Id
	cloudType	 (string):	Cloud Type
	connectType	 (string):	Connect Type filter
	vxcPermitted	 (string):	VXC Permitted on the port
	authorizationKey	 (string):	authorization Key
	refresh	 (string):	Refresh
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/partnerports/edge?edgeType={edgeType}&accountId={accountId}&cloudType={cloudType}&connectType={connectType}&vxcPermitted={vxcPermitted}&authorizationKey={authorizationKey}&refresh={refresh}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getPortSpeed(vmanage, edgeType, edgeAccountId, connectivityType, cloudType, cloudAccountId, connectType, connectSubType, connectivityGateway, partnerPort):
    """
    Get supported port speed
    
    Parameters:
    edgeType	 (string):	Interconnect Provider
	edgeAccountId	 (string):	Interconnect Provider Account ID
	connectivityType	 (string):	Interconnect Connectivity Type
	cloudType	 (string):	Cloud Service Provider
	cloudAccountId	 (string):	Cloud Service Provider Account ID
	connectType	 (string):	Connection Type filter
	connectSubType	 (string):	Connection Sub-Type filter
	connectivityGateway	 (string):	Connectivity Gateway
	partnerPort	 (string):	partnerPort
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/portSpeed/edge/{edgeType}/{edgeAccountId}/{connectivityType}?cloudType={cloudType}&cloudAccountId={cloudAccountId}&connectType={connectType}&connectSubType={connectSubType}&connectivityGateway={connectivityGateway}&partnerPort={partnerPort}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getCloudRegions(vmanage, cloudType):
    """
    Get cloud regions
    
    Parameters:
    cloudType	 (string):	Cloud type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/regions?cloudType={cloudType}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getEdgeGlobalSettings(vmanage, edgeType):
    """
    Get edge global settings
    
    Parameters:
    edgeType	 (string):	Edge type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/settings/edge/global?edgeType={edgeType}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def updateEdgeGlobalSettings(vmanage, globalsetting):
    """
    Update edge global settings for Edge provider
    
    Parameters:
    globalsetting:	Global setting
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/settings/edge/global"
    response = vmanage.apiCall("PUT", endpoint, globalsetting)
    return response

def addEdgeGlobalSettings(vmanage, globalsetting):
    """
    Add global settings for Edge provider
    
    Parameters:
    globalsetting:	Global setting
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/settings/edge/global"
    response = vmanage.apiCall("POST", endpoint, globalsetting)
    return response

def getGlobalSettings(vmanage, cloudType):
    """
    Get global settings
    
    Parameters:
    cloudType	 (string):	Cloud type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/settings/global?cloudType={cloudType}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def updateGlobalSettings(vmanage, globalsetting):
    """
    Update ip in resource pool
    
    Parameters:
    globalsetting:	Global setting
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/settings/global"
    response = vmanage.apiCall("PUT", endpoint, globalsetting)
    return response

def addGlobalSettings(vmanage, globalsetting):
    """
    Acquire ip from resource pool
    
    Parameters:
    globalsetting:	Global setting
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/settings/global"
    response = vmanage.apiCall("POST", endpoint, globalsetting)
    return response

def getSites(vmanage, color, attached):
    """
    Get available sites
    
    Parameters:
    color	 (string):	Color
	attached	 (boolean):	Is endpoint attached
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/site?color={color}&attached={attached}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getSshKeyList(vmanage, cloudType, accountId, cloudRegion):
    """
    Get SSH keys
    
    Parameters:
    cloudType	 (string):	Cloud type
	accountId	 (string):	Account Id
	cloudRegion	 (string):	Region
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/sshkeys?cloudType={cloudType}&accountId={accountId}&cloudRegion={cloudRegion}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getPostAggregationDataByQuery(vmanage, statsquerystring):
    """
    Get aggregated data based on input query and filters. The data can be filtered on time and other unique parameters based upon necessity and intended usage
    
    Parameters:
    statsquerystring:	Stats query string
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/statistics/interface/aggregation"
    response = vmanage.apiCall("POST", endpoint, statsquerystring)
    return response

def getSupportedSoftwareImageList(vmanage, cloudType, accountId, cloudRegion):
    """
    Get software image list
    
    Parameters:
    cloudType	 (string):	Cloud type
	accountId	 (string):	Account Id
	cloudRegion	 (string):	Region
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/swimages?cloudType={cloudType}&accountId={accountId}&cloudRegion={cloudRegion}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def telemetry(vmanage, telemetry):
    """
    reports telemetry data
    
    Parameters:
    telemetry:	telemetry
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/telemetry"
    response = vmanage.apiCall("POST", endpoint, telemetry)
    return response

def getTunnelNames(vmanage, cloudType, cgName):
    """
    Get tunnel names
    
    Parameters:
    cloudType	 (string):	Cloud type
	cgName	 (string):	Cloud gateway name
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/tunnels/{cloudType}?cloudGatewayName={cgName}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getCloudTypes(vmanage):
    """
    Get cloud types
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/types"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getEdgeTypes(vmanage):
    """
    Get edge types
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/types/edge"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getVHubs(vmanage, cloudType, accountId, resourceGroup, vWanName, vNetTags):
    """
    Get Virtual Hubs
    
    Parameters:
    cloudType	 (string):	Cloud Type
	accountId	 (string):	Account Id
	resourceGroup	 (string):	Resource Group
	vWanName	 (string):	VWan Name
	vNetTags	 (string):	VNet Tags
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/vhubs?cloudType={cloudType}&accountId={accountId}&resourceGroup={resourceGroup}&vWanName={vWanName}&vNetTags={vNetTags}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def createVirtualWan(vmanage, virtualwan):
    """
    Create Virtual WAN
    
    Parameters:
    virtualwan:	Virtual WAN
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/vwan"
    response = vmanage.apiCall("POST", endpoint, virtualwan)
    return response

def deleteVirtualWan(vmanage, cloudProvider, vWanName):
    """
    Delete Virtual Wan
    
    Parameters:
    cloudProvider	 (string):	Cloud Provider
	vWanName	 (string):	Virtual Wan name
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/vwan/{cloudProvider}/{vWanName}"
    response = vmanage.apiCall("DELETE", endpoint)
    return response

def getVWans(vmanage, accountId, cloudType, resourceGroup, refresh):
    """
    Get Virtual Wans
    
    Parameters:
    accountId	 (string):	Account Id
	cloudType	 (string):	Cloud Type
	resourceGroup	 (string):	Resource Group
	refresh	 (string):	Refresh
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/vwans?accountId={accountId}&cloudType={cloudType}&resourceGroup={resourceGroup}&refresh={refresh}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getEdgeWidget(vmanage, edgeType):
    """
    Get Interconnect Edge widget by edge type
    
    Parameters:
    edgeType	 (string):	Edge type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/widget/edge/{edgeType}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getCloudWidget(vmanage, cloudType):
    """
    Get cloud widget by cloud type
    
    Parameters:
    cloudType	 (string):	Cloud type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/multicloud/widget/{cloudType}"
    response = vmanage.apiCall("GET", endpoint)
    return response



from py_viptela.api.monitoring import aar
from py_viptela.api.monitoring import aarstats
from py_viptela.api.monitoring import alarm
from py_viptela.api.monitoring import apphosting
from py_viptela.api.monitoring import apphostingif
from py_viptela.api.monitoring import art
from py_viptela.api.monitoring import bfd
from py_viptela.api.monitoring import bridgeif
from py_viptela.api.monitoring import bridgemac
from py_viptela.api.monitoring import cflowd
from py_viptela.api.monitoring import cflowdflows
from py_viptela.api.monitoring import cloudexp
from py_viptela.api.monitoring import colocation
from py_viptela.api.monitoring import devicedetails
from py_viptela.api.monitoring import devicestats
from py_viptela.api.monitoring import devicestatsdetails
from py_viptela.api.monitoring import dpi
from py_viptela.api.monitoring import dpiod
from py_viptela.api.monitoring import eiolte
from py_viptela.api.monitoring import events
from py_viptela.api.monitoring import flowlog
from py_viptela.api.monitoring import interfacestats
from py_viptela.api.monitoring import ipsalert
from py_viptela.api.monitoring import qos
from py_viptela.api.monitoring import security
from py_viptela.api.monitoring import server
from py_viptela.api.monitoring import servicechain
from py_viptela.api.monitoring import statsdownload
from py_viptela.api.monitoring import statsprocessing
from py_viptela.api.monitoring import status
from py_viptela.api.monitoring import systemstatus
from py_viptela.api.monitoring import umbrella
from py_viptela.api.monitoring import umbrellapatterns
from py_viptela.api.monitoring import urlfiltering
from py_viptela.api.monitoring import wlanclientinfo


def downloadData(vmanage, path):
    """
    Download tenant data
    
    Parameters:
    path	 (string):	File path
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/tenantmigration/download/{path}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def exportData(vmanage, bodyParameter):
    """
    Export tenant data
    
    Parameters:
    bodyParameter:	Description
    
    bodyParameter  example
    param = {
        "desc": "string",
        "getvBondAddress": "string",
        "idpMetadata": "string",
        "mode": "string",
        "name": "string",
        "oldIdpMetadata": "string",
        "orgName": "string",
        "spMetadata": "string",
        "subDomain": "string",
        "wanEdgeForecast": "string"
    }
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/tenantmigration/export"
    response = vmanage.apiCall("POST", endpoint, bodyParameter)
    return response
def importData(vmanage):
    """
    Import tenant data
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/tenantmigration/import"
    response = vmanage.apiCall("POST", endpoint)
    return response
def getToken(vmanage, migrationId):
    """
    Get migration token
    
    Parameters:
    migrationId	 (string):	Migration Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/tenantmigration/migrationToken?migrationId={migrationId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def reTrigger(vmanage):
    """
    Re-trigger network migration
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/tenantmigration/networkMigration"
    response = vmanage.apiCall("GET", endpoint)
    return response
def migrate(vmanage, networkMigration):
    """
    Migrate network
    
    Parameters:
    networkMigration:	Network migration
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/tenantmigration/networkMigration"
    response = vmanage.apiCall("POST", endpoint, networkMigration)
    return response



def get(vmanage):
    """
    Get list of firmware images in the repository
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/firmware"
    response = vmanage.apiCall("GET", endpoint)
    return response

def process(vmanage):
    """
    Upload firmware image package
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/firmware"
    response = vmanage.apiCall("POST", endpoint)
    return response

def activate(vmanage, fwInfo):
    """
    Activate firmware on device
    
    Parameters:
    fwInfo:    Firmware Info
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/firmware/activate"
    response = vmanage.apiCall("POST", endpoint, fwInfo)
    return response

def getDevicesFWUpgrade(vmanage):
    """
    Get list of devices that support firmware upgrade
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/firmware/devices"
    response = vmanage.apiCall("GET", endpoint)
    return response

def install(vmanage, fwInfo):
    """
    Install firmware on device
    
    Parameters:
    fwInfo:    Firmware Info
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/firmware/install"
    response = vmanage.apiCall("POST", endpoint, fwInfo)
    return response

def remove(vmanage, fwInfo):
    """
    Remove firmware on device
    
    Parameters:
    fwInfo:    Firmware Info
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/firmware/remove"
    response = vmanage.apiCall("POST", endpoint, fwInfo)
    return response

def getDetails(vmanage, versionId):
    """
    Get firmware image details for a given version
    
    Parameters:
    versionId	 (string):	Firmware image version
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/firmware/{versionId}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def delete(vmanage, versionId):
    """
    Delete firmware image package
    
    Parameters:
    versionId	 (string):	Firmware image version
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/firmware/{versionId}"
    response = vmanage.apiCall("DELETE", endpoint)
    return response



def getClients(vmanage, deviceId):
    """
    Get DOT1x client from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/dot1x/clients?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getInterfaces(vmanage, deviceId):
    """
    Get DOT1x interface from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/dot1x/interfaces?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getRadius(vmanage, deviceId):
    """
    Get DOT1x Radius from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/dot1x/radius?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response



def getVbranchNics(vmanage, deviceId):
    """
    Get vbranch vm lifecycle state (NIC)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/vm/nics?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getCloudDockNics(vmanage, userGroup):
    """
    Get CloudDock vm lifecycle state
    
    Parameters:
    userGroup	 (string):	userGroup Name
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/vm/notifications?userGroup={userGroup}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getVbranch(vmanage, deviceId):
    """
    Get vbranch vm lifecycle state
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/vm/oper/state?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getState(vmanage, deviceId):
    """
    Get vm lifecycle state
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/vm/state?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response



def getAclAssociations(vmanage, deviceId):
    """
    Get access list associations from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/policy/accesslistassociations?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getAclCounters(vmanage, deviceId):
    """
    Get access list counter from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/policy/accesslistcounters?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getAclNames(vmanage, deviceId):
    """
    Get access list names from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/policy/accesslistnames?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getAclPolicers(vmanage, deviceId):
    """
    Get access list policers from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/policy/accesslistpolicers?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getAppRouteFilter(vmanage, deviceId):
    """
    Get approute policy filter from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/policy/approutepolicyfilter?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getDataPolicyFilter(vmanage, deviceId):
    """
    Get data policy filters from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/policy/datapolicyfilter?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getFilterMemUsage(vmanage, deviceId):
    """
    Get data policy filter memory usage from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/policy/filtermemoryusage?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getAclAssocV6(vmanage, deviceId):
    """
    Get access list associations from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/policy/ipv6/accesslistassociations?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getAclCountersV6(vmanage, deviceId):
    """
    Get access list counters from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/policy/ipv6/accesslistcounters?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getAclNamesV6(vmanage, deviceId):
    """
    Get access list names from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/policy/ipv6/accesslistnames?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getAclPolicersV6(vmanage, deviceId):
    """
    Get access list policers from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/policy/ipv6/accesslistpolicers?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getQosMapInfo(vmanage, deviceId):
    """
    Get QoS map information from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/policy/qosmapinfo?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getQosSchedulerInfo(vmanage, deviceId):
    """
    Get QoS scheduler information from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/policy/qosschedulerinfo?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getRewriteAssocInfo(vmanage, deviceId):
    """
    Get rewrite associations information from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/policy/rewriteassociations?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getSdwanPolicyFromVsmart(vmanage, deviceId):
    """
    show Sdwan Policy From Vsmart
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/policy/vsmart?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getZoneDropStats(vmanage, deviceId):
    """
    Get zone drop statistics from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/policy/zbfwdropstatistics?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getZbfwStats(vmanage, deviceId):
    """
    Get zone based firewall statistics from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/policy/zbfwstatistics?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getZonePairSessions(vmanage, deviceId):
    """
    Get zone pair sessions from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/policy/zonepairsessions?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getZonePairs(vmanage, deviceId):
    """
    Get zone pair statistics from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/policy/zonepairstatistics?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getZonePolicyFilters(vmanage, deviceId):
    """
    Get zone policy filter from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/policy/zonepolicyfilter?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response



def getAlarms(vmanage, query):
    """
    Get alarms for last 30min if vManage query is not specified
    
    Parameters:
    query	 (dict):	 query data
    
    Returns
    response    (dict)
    
    Example query dictionary:
    query =   {"query": {"field": "active","type": "boolean", "value": ["true"], "operator": "equal" }}
    """
    
    query_string = vmanage.builder.generateQuery(query)
    endpoint = f"dataservice/alarms?query={query_string}"
    response     = vmanage.apiCall("GET", endpoint)
    return response
def getRawData(vmanage, alarmquerystring):
    """
    Gets lists of alarms along with the raw alarm data of each.
    
    Parameters:
    alarmquerystring:	Alarm query string
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/alarms"
    response = vmanage.apiCall("POST", endpoint, alarmquerystring)
    return response
def getAggregationData(vmanage, query):
    """
    Gets aggregated list of alarms along with the raw alarm data of each aggregation
    
    Parameters:
    query	 (string):	Alarm query dict
    
    Returns
    response    (dict)
    
    
    """
    query_string = vmanage.builder.generateQuery(query)
    endpoint = f"dataservice/alarms/aggregation?query={query_string}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getPostAggregationData(vmanage, inputquery):
    """
    Gets aggregated list of alarms along with the raw alarm data of each aggregation
    
    Parameters:
    inputquery:	Input query
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/alarms/aggregation"
    response = vmanage.apiCall("POST", endpoint, inputquery)
    return response
def clearStale(vmanage, alarm_uuid):
    """
    Clears specific stale alarm
    
    Parameters:
    alarm_uuid:	alarm_uuid
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/alarms/clear"
    response = vmanage.apiCall("POST", endpoint, alarm_uuid)
    return response
def getNonViewedActiveCount(vmanage):
    """
    Get count of the alarms which are active and acknowledged by the user
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/alarms/count"
    response = vmanage.apiCall("GET", endpoint)
    return response
def listDisabled(vmanage):
    """
    List all disabled alarms
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/alarms/disabled"
    response = vmanage.apiCall("GET", endpoint)
    return response
def disableEnable(vmanage, alarmconfig, eventName, disable, time):
    """
    Enable/Disable a specific alarm
    
    Parameters:
    alarmconfig:	    alarm config
	eventName	 (string):	Event name
	disable	    (boolean):	Disable
	time	    (integer):	time in hours [1, 72], -1 means infinite
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/alarms/disabled?eventName={eventName}&disable={disable}&time={time}"
    response = vmanage.apiCall("POST", endpoint, alarmconfig)
    return response
def getCount(vmanage, query):
    """
    Get response count of a query
    
    Parameters:
    query	 (string):	Query
    
    Returns
    response    (dict)
    
    
    """
    query_string = vmanage.builder.generateQuery(query)
    endpoint = f"dataservice/alarms/doccount?query={query_string}"
    response     = vmanage.apiCall("GET", endpoint)
    return response
def getCountPost(vmanage, query):
    """
    Get response count of a query
    
    Parameters:
    query:	Query
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/alarms/doccount"
    response = vmanage.apiCall("POST", endpoint, query)
    return response
def dumpCorrelationEngineData(vmanage):
    """
    dump correlation engine server data
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/alarms/dump"
    response = vmanage.apiCall("POST", endpoint)
    return response
def getStatDataFields(vmanage):
    """
    Get fields and type
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/alarms/fields"
    response = vmanage.apiCall("GET", endpoint)
    return response
def markAllAsViewed(vmanage, bodyParameter, type):
    """
    Mark all larms as acknowledged by the user
    
    Parameters:
    bodyParameter:	Description
	type	 (string):	Query filter, possible value are "active" "cleared"
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/alarms/markallasviewed?type={type}"
    response = vmanage.apiCall("POST", endpoint, bodyParameter)
    return response
def markAsViewed(vmanage, listofalarms):
    """
    Mark alarms as acknowledged by the user
    
    Parameters:
    listofalarms:	List of alarms
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/alarms/markviewed"
    response = vmanage.apiCall("POST", endpoint, listofalarms)
    return response
def getMasterManagerState(vmanage):
    """
    Get master manager state
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/alarms/master"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getNonViewed(vmanage):
    """
    Get alarms which are active and acknowledged by the user
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/alarms/notviewed"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getStatBulkAlarmRawData(vmanage, query, scrollId, count):
    """
    Get paginated alarm raw data
    
    Parameters:
    query	     (string):	Alarm query string
	scrollId	 (string):	Query offset
	count	    (integer):	Query size
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/alarms/page?query={query}&scrollId={scrollId}&count={count}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getPostStatBulkAlarmRawData(vmanage, alarmquerystring, scrollId, count):
    """
    Get paginated alarm raw data
    
    Parameters:
    alarmquerystring:	    Alarm query string
	scrollId	 (string):	Query offset
	count	    (integer):	Query size
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/alarms/page?scrollId={scrollId}&count={count}"
    response = vmanage.apiCall("POST", endpoint, alarmquerystring)
    return response
def setPeriodicPurgeTimer(vmanage, interval, activeTime):
    """
    Set alarm purge timer
    
    Parameters:
    interval	 (string):	Purge interval
	activeTime	 (string):	Purge activeTime
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/alarms/purgefrequency?interval={interval}&activeTime={activeTime}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getStatQueryFields(vmanage):
    """
    Get query fields
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/alarms/query/fields"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getQueryConfig(vmanage):
    """
    Get query configuration
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/alarms/query/input"
    response = vmanage.apiCall("GET", endpoint)
    return response
def correlAntiEntropy(vmanage):
    """
    Reset correlation engine data
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/alarms/reset"
    response = vmanage.apiCall("GET", endpoint)
    return response
def restartCorrelationEngine(vmanage):
    """
    Restart correlation engine
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/alarms/restart"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getTypesAsKeyValue(vmanage):
    """
    Gets alarm type as key value pair
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/alarms/rulenamedisplay/keyvalue"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getBySeverity(vmanage, level, deviceId, query):
    """
    Get alarm by severity
    
    Parameters:
    level	     (array):	Alarm severity
	deviceId	 (array):	Device Id
	query	    (string):	Query filter
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/alarms/severity?severity-level={level}&deviceId={deviceId}&query={query}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getSeverityCustomHistogram(vmanage, query):
    """
    Get alarm severity histogram
    
    Parameters:
    query	 (string):	Alarm histogram query string
    
    Returns
    response    (dict)
    
    
    """
    query_string = vmanage.builder.generateQuery(query)
    endpoint = f"dataservice/alarms/severity/summary?query={query_string}"
    response     = vmanage.apiCall("GET", endpoint)
    return response
def getSeverityMappings(vmanage):
    """
    Gets alarm severity mappings
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/alarms/severitymappings"
    response = vmanage.apiCall("GET", endpoint)
    return response
def startTracking(vmanage, testName):
    """
    Start tracking events
    
    Parameters:
    testName	 (string):	test name
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/alarms/starttracking/{testName}"
    response = vmanage.apiCall("POST", endpoint)
    return response
def getStats(vmanage):
    """
    Get alarm statistics
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/alarms/stats"
    response = vmanage.apiCall("GET", endpoint)
    return response
def stopTracking(vmanage, testName):
    """
    Stop tracking events
    
    Parameters:
    testName	 (string):	test name
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/alarms/stoptracking/{testName}"
    response = vmanage.apiCall("POST", endpoint)
    return response
def getDeviceTopic(vmanage, ip):
    """
    Get device topic state
    
    Parameters:
    ip	 (string):	Query topic
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/alarms/topic?ip={ip}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getDetails(vmanage, alarm_uuid):
    """
    Get alarm detail
    
    Parameters:
    alarm_uuid	 (string):	Alarm Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/alarms/uuid/{alarm_uuid}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def updateNotificationRule(vmanage, notificationrule, ruleId):
    """
    Update notification rule
    
    Parameters:
    notificationrule:	Notification rule
	ruleId	 (string):	Rule Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/notifications/rule?ruleId={ruleId}"
    response = vmanage.apiCall("PUT", endpoint, notificationrule)
    return response
def createNotificationRule(vmanage, notificationrule):
    """
    Add notification rule
    
    Parameters:
    notificationrule:	Notification rule
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/notifications/rule"
    response = vmanage.apiCall("POST", endpoint, notificationrule)
    return response
def getNotificationRule(vmanage, ruleId):
    """
    Get all rules or specific notification rule by its Id
    
    Parameters:
    ruleId	 (string):	Rule Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/notifications/rules?ruleId={ruleId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def deleteNotificationRule(vmanage, ruleId):
    """
    Delete notification rule
    
    Parameters:
    ruleId	 (string):	Rule Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/notifications/rules?ruleId={ruleId}"
    response = vmanage.apiCall("DELETE", endpoint)
    return response



def uploadConfig(vmanage, templateconfig, deviceId):
    """
    Upload device config
    
    Parameters:
    templateconfig:	Template config
	deviceId	 (string):	Device Model ID
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/config/attach/{deviceId}"
    response = vmanage.apiCall("PUT", endpoint, templateconfig)
    return response

def getAttached(vmanage, deviceId, type):
    """
    Get local template attached config for given device
    
    Parameters:
    deviceId	 (string):	Device Model ID
	type	 (string):	Config type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/config/attached/{deviceId}?type={type}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getCLIModeDevices(vmanage, type):
    """
    Generates a JSON object that contains a list of valid devices in CLI mode
    
    Parameters:
    type	 (string):	Device type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/config/device/mode/cli?type={type}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def updateToCLI(vmanage, devicelist):
    """
    Given a JSON list of devices not managed by any third member partners, push to devices from a CLI template
    
    Parameters:
    devicelist:	Device list
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/config/device/mode/cli"
    response = vmanage.apiCall("POST", endpoint, devicelist)
    return response

def getvManageModeDevices(vmanage, type):
    """
    Get list of devices that are allowable for vmanage modes
    
    Parameters:
    type	 (string):	Device type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/config/device/mode/vmanage?type={type}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getDeviceDiff(vmanage, deviceId):
    """
    Generates a JSON object that contains the diff for a given device
    
    Parameters:
    deviceId	 (string):	Device Model ID
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/config/diff/{deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getCompatibleDevices(vmanage, oldDeviceId):
    """
    Get compatible devices of model, chassis number, certificate serial number with the old device
    
    Parameters:
    oldDeviceId	 (string):	Device Model ID
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/config/rmalist/{oldDeviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def rmaUpdate(vmanage, templateconfig):
    """
    Update new device
    
    Parameters:
    templateconfig:	Template config
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/config/rmaupdate"
    response = vmanage.apiCall("PUT", endpoint, templateconfig)
    return response

def getRunningConfig(vmanage, deviceId):
    """
    Get device running config
    
    Parameters:
    deviceId	 (string):	Device Model ID
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/config/running/{deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getVpnForDevice(vmanage, deviceId):
    """
    Get list of configured VPN (excluding reserved VPN) for a device
    
    Parameters:
    deviceId	 (string):	Device Model ID
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/config/vpn/{deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response



def getStateData(vmanage, state_data_type, startId, count):
    """
    Get device state data
    
    Parameters:
    state_data_type	 (string):	State data type
	startId	 (string):	Start Id
	count	 (string):	Count
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/data/device/state/{state_data_type}?startId={startId}&count={count}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getStateDataFields(vmanage, state_data_type):
    """
    Get device state data fileds
    
    Parameters:
    state_data_type	 (string):	State data type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/data/device/state/{state_data_type}/fields"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getStateDataWithQuery(vmanage, state_data_type):
    """
    Get device state data fileds
    
    Parameters:
    state_data_type	 (string):	State data type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/data/device/state/{state_data_type}/query"
    response = vmanage.apiCall("GET", endpoint)
    return response
def listAllDevices(vmanage):
    """
    List all devices
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device"
    response = vmanage.apiCall("GET", endpoint)
    return response
def setBlockSync(vmanage, blockSync):
    """
    Set collection manager block set flag
    
    Parameters:
    blockSync	 (string):	Block sync flag
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/blockSync?blockSync={blockSync}"
    response = vmanage.apiCall("POST", endpoint)
    return response
def getRunning(vmanage, deviceId):
    """
    Get device running configuration
    
    Parameters:
    deviceId	 (array):	Device Id list
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/config?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getRunningHtml(vmanage, deviceId):
    """
    Get device running configuration in HTML format
    
    Parameters:
    deviceId	 (array):	Device Id list
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/config/html?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getDeviceCounters(vmanage):
    """
    Get device counters
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/counters"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getDeviceOnlyStatus(vmanage):
    """
    Get devices status per type
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/devicestatus"
    response = vmanage.apiCall("GET", endpoint)
    return response
def enableSDAVCOnDevice(vmanage, deviceIP, enable):
    """
    Enable/Disable SDAVC on device
    
    Parameters:
    deviceIP	 (string):	Device IP
	enable	 (boolean):	Enable/Disable flag
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/enableSDAVC/{deviceIP}/{enable}"
    response = vmanage.apiCall("POST", endpoint)
    return response
def getHealthDetails(vmanage, deviceId, state):
    """
    Get hardware health details for device
    
    Parameters:
    deviceId	 (string):	Device Id
	state	 (string):	Device state
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/hardwarehealth/detail?deviceId={deviceId}&state={state}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getHealthSummary(vmanage, isCached, vpnId):
    """
    Get hardware health summary for device
    
    Parameters:
    isCached	 (boolean):	Status cached
	vpnId	 (array):	VPN Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/hardwarehealth/summary?isCached={isCached}&vpnId={vpnId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getListAsKeyValue(vmanage):
    """
    Get vEdge inventory as key value (key as systemIp value as hostName)
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/keyvalue"
    response = vmanage.apiCall("GET", endpoint)
    return response
def listAllModels(vmanage, list):
    """
    Get all device models supported by the vManage
    
    Parameters:
    list	 (string):	List type of device
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/models?list={list}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getDeviceModels(vmanage, uuid):
    """
    Get device model for the device
    
    Parameters:
    uuid	 (string):	Device uuid
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/models/{uuid}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def listAllMonitorDetails(vmanage):
    """
    Get all monitoring details of the devices
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/monitor"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getSyncQueues(vmanage):
    """
    Get synchronized queue information, returns information about syncing, queued and stuck devices
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/queues"
    response = vmanage.apiCall("GET", endpoint)
    return response
def listReachable(vmanage):
    """
    Get list of reachable devices
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/reachable"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getStatsQueues(vmanage):
    """
    Get stats queue information
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/stats"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getAllStatus(vmanage):
    """
    Get devices status for vSmart,vBond,vEdge, and cEdge
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/status"
    response = vmanage.apiCall("GET", endpoint)
    return response
def listSyncing(vmanage, groupId):
    """
    Get list of currently syncing devices
    
    Parameters:
    groupId	 (string):	Group Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/sync_status?groupId={groupId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def syncAllMemDB(vmanage):
    """
    Synchronize memory database for all devices
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/syncall/memorydb"
    response = vmanage.apiCall("POST", endpoint)
    return response
def getDeviceTlocStatus(vmanage, deviceId, color):
    """
    Get TLOC status list
    
    Parameters:
    deviceId	 (string):	Device Id
	color	 (string):	Status color
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/tloc?deviceId={deviceId}&color={color}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getTlocUtil(vmanage):
    """
    Get TLOC list
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/tlocutil"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getTlocUtilDetails(vmanage, util):
    """
    Get detailed TLOC list
    
    Parameters:
    util	 (string):	Tloc util
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/tlocutil/detail?util={util}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def listUnreachable(vmanage, personality):
    """
    Get list of unreachable devices
    
    Parameters:
    personality	 (string):	Device personality
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/unreachable?personality={personality}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def removeUnreachable(vmanage, deviceIP):
    """
    Delete unreachable device
    
    Parameters:
    deviceIP	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/unreachable/{deviceIP}"
    response = vmanage.apiCall("DELETE", endpoint)
    return response
def getVedgeInventory(vmanage, status):
    """
    Get detailed vEdge inventory
    
    Parameters:
    status	 (string):	Device status
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/vedgeinventory/detail?status={status}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getVedgeInventorySummary(vmanage):
    """
    Get vEdge inventory
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/vedgeinventory/summary"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getVManageSystemIP(vmanage):
    """
    Get vManage system IP
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/vmanage"
    response = vmanage.apiCall("GET", endpoint)
    return response



def getInterfaces(vmanage, deviceId):
    """
    Get device bridge interface list (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/bridge/interface?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getInterfaceMac(vmanage, bridgeId, ifName, macAddr, deviceId):
    """
    Get device bridge interface MAC (Real Time)
    
    Parameters:
    bridgeId	 (string):	Bridge ID
	ifName	 (string):	Interface name
	macAddr	 (string):	MAC address
	deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/bridge/mac?bridgeId={bridgeId}&ifName={ifName}&macAddr={macAddr}&deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getBridgeInterfaceTable(vmanage, deviceId):
    """
    Get device bridge interface table (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/bridge/table?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response



def getUTDDataplaneConfig(vmanage, deviceId):
    """
    Get data plane config from Device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/utd/dataplane-config?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getUTDDataplaneGlobal(vmanage, deviceId):
    """
    Get data plane global from Device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/utd/dataplane-global?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getUTDDataplaneStats(vmanage, deviceId):
    """
    Get data plane stats from Device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/utd/dataplane-stats?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getUTDDataplaneStatsSummary(vmanage, deviceId):
    """
    Get data plane stats summary
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/utd/dataplane-stats-summary?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getUTDEngineInstanceStatus(vmanage, deviceId):
    """
    Get UTD engine instance status from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/utd/engine-instance-status?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getUTDEngineStatus(vmanage, deviceId):
    """
    Get UTD engine status from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/utd/engine-status?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getUTDFileAnalysisStatus(vmanage, deviceId):
    """
    Get UTD file analysis status from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/utd/file-analysis-status?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getUTDFileReputationStatus(vmanage, deviceId):
    """
    Get UTD file reputation status from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/utd/file-reputation-status?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getUTDIpsUpdateStatus(vmanage, deviceId):
    """
    Get UTD IPS update status from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/utd/ips-update-status?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getSignatureVersionInfo(vmanage, deviceId):
    """
    Get UTD Signature version information from Device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/utd/signature/version/details?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getUTDUrlfConnectionStatus(vmanage, deviceId):
    """
    Get UTD URLF Connection status from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/utd/urlf-con-status?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getUTDUrlfUpdateStatus(vmanage, deviceId):
    """
    Get UTD URLF update status from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/utd/urlf-update-status?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getUTDVersionStatus(vmanage, deviceId):
    """
    Get UTD version status from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/utd/version-status?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response



def createUcseStats(vmanage, remote_tloc_address, remote_tloc_color, local_tloc_color, deviceId):
    """
    Get  UCSE stats entry from device
    
    Parameters:
    remote_tloc_address	 (string):	Remote TLOC address
	remote_tloc_color	 (string):	Remote tloc color
	local_tloc_color	 (string):	Local tloc color
	deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/ucse/stats?remote-tloc-address={remote_tloc_address}&remote-tloc-color={remote_tloc_color}&local-tloc-color={local_tloc_color}&deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response



from py_viptela.api.config.device import actions
from py_viptela.api.config.device import confighist
from py_viptela.api.config.device import fwupdate
from py_viptela.api.config.device import inventory
from py_viptela.api.config.device import proxy
from py_viptela.api.config.device import swpack
from py_viptela.api.config.device import swupdate



def listDeviceGroupList(vmanage):
    """
    Retrieve device group list
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/group"
    response = vmanage.apiCall("GET", endpoint)
    return response
def listDeviceGroups(vmanage):
    """
    Retrieve device groups
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/group/device"
    response = vmanage.apiCall("GET", endpoint)
    return response
def listGroupDevices(vmanage, groupId, ssh, vpnId):
    """
    Retrieve devices in group
    
    Parameters:
    groupId	 (string):	Group Id
	ssh	 (boolean):	SSH
	vpnId	 (array):	VPN Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/group/devices?groupId={groupId}&ssh={ssh}&vpnId={vpnId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def listGroupDevicesForMap(vmanage, groupId, vpnId):
    """
    Retrieve group devices for map
    
    Parameters:
    groupId	 (string):	Group Id
	vpnId	 (array):	VPN Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/group/map/devices?groupId={groupId}&vpnId={vpnId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def listGroupLinksForMap(vmanage, groupId):
    """
    Retrieve devices in group for map
    
    Parameters:
    groupId	 (string):	Group Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/group/map/devices/links?groupId={groupId}"
    response = vmanage.apiCall("GET", endpoint)
    return response



def invalidateDevice(vmanage, devInfo):
    """
    invalidate the device
    
    Parameters:
    devInfo:	vEdge device info
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/certificate/device/invalidate"
    response = vmanage.apiCall("POST", endpoint, devInfo)
    return response
def stageDevice(vmanage, devInfo):
    """
    Stop data traffic to device
    
    Parameters:
    devInfo:	vEdge device info
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/certificate/device/stage"
    response = vmanage.apiCall("POST", endpoint, devInfo)
    return response
def createAdminTech(vmanage, request):
    """
    Generate admin tech logs
    
    Parameters:
    request:	Admin tech generation request
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/tools/admintech"
    response = vmanage.apiCall("POST", endpoint, request)
    return response
def copyAdminTechOnDevice(vmanage, request):
    """
    copy admin tech logs
    
    Parameters:
    request:	Admin tech copy request
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/tools/admintech/copy"
    response = vmanage.apiCall("POST", endpoint, request)
    return response
def deleteAdminTechOnDevice(vmanage, request):
    """
    delete admin tech logs
    
    Parameters:
    request:	Admin tech copy request
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/tools/admintech/delete"
    response = vmanage.apiCall("DELETE", endpoint, request)
    return response
def downloadAdminTechFile(vmanage, filename):
    """
    Download admin tech logs
    
    Parameters:
    filename	 (string):	Admin tech file
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/tools/admintech/download/{filename}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def deleteAdminTechFile(vmanage, requestID):
    """
    Delete admin tech logs
    
    Parameters:
    requestID	 (string):	Request Id of admin tech generation request
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/tools/admintech/{requestID}"
    response = vmanage.apiCall("DELETE", endpoint)
    return response
def listAdminTechsOnDevice(vmanage, request):
    """
    List admin tech logs
    
    Parameters:
    request:	Admin tech listing request
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/tools/admintechlist"
    response = vmanage.apiCall("POST", endpoint, request)
    return response
def listAdminTechs(vmanage):
    """
    Get device admin-tech information
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/tools/admintechs"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getInProgressCount(vmanage):
    """
    Get device admin-tech InProgressCount
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/tools/admintechs/inprogress"
    response = vmanage.apiCall("GET", endpoint)
    return response
def factoryReset(vmanage, payload):
    """
    Device factory reset
    
    Parameters:
    payload:	Device factory reset
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/tools/factoryreset"
    response = vmanage.apiCall("POST", endpoint, payload)
    return response
def npingDevice(vmanage, npingparameter, deviceIP):
    """
    NPing device
    
    Parameters:
    npingparameter:	NPing parameter
	deviceIP	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/tools/nping/{deviceIP}"
    response = vmanage.apiCall("POST", endpoint, npingparameter)
    return response
def pingDevice(vmanage, pingparameter, deviceIP):
    """
    Ping device
    
    Parameters:
    pingparameter:	Ping parameter
	deviceIP	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/tools/ping/{deviceIP}"
    response = vmanage.apiCall("POST", endpoint, pingparameter)
    return response
def processPortHopColor(vmanage, deviceporthopcolor, deviceIP):
    """
    Request port hop color
    
    Parameters:
    deviceporthopcolor:	Device port hop color
	deviceIP	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/tools/porthopcolor/{deviceIP}"
    response = vmanage.apiCall("POST", endpoint, deviceporthopcolor)
    return response
def processInterfaceReset(vmanage, deviceinterface, deviceIP):
    """
    Reset device interface
    
    Parameters:
    deviceinterface:	Device interface
	deviceIP	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/tools/reset/interface/{deviceIP}"
    response = vmanage.apiCall("POST", endpoint, deviceinterface)
    return response
def processResetUser(vmanage, deviceuserreset, deviceIP):
    """
    Request reset user
    
    Parameters:
    deviceuserreset:	Device user reset
	deviceIP	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/tools/resetuser/{deviceIP}"
    response = vmanage.apiCall("POST", endpoint, deviceuserreset)
    return response
def servicePath(vmanage, servicepathparameter, deviceIP):
    """
    Service path
    
    Parameters:
    servicepathparameter:	Service path parameter
	deviceIP	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/tools/servicepath/{deviceIP}"
    response = vmanage.apiCall("POST", endpoint, servicepathparameter)
    return response
def tracerouteDevice(vmanage, tracerouteparameter, deviceIP):
    """
    Traceroute
    
    Parameters:
    tracerouteparameter:	Traceroute parameter
	deviceIP	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/tools/traceroute/{deviceIP}"
    response = vmanage.apiCall("POST", endpoint, tracerouteparameter)
    return response
def tunnelPath(vmanage, tunnelpathparameter, deviceIP):
    """
    TunnelPath
    
    Parameters:
    tunnelpathparameter:	TunnelPath parameter
	deviceIP	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/tools/tunnelpath/{deviceIP}"
    response = vmanage.apiCall("POST", endpoint, tunnelpathparameter)
    return response
def getControlConnections(vmanage, uuid):
    """
    Troubleshoot control connections
    
    Parameters:
    uuid	 (string):	Device uuid
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/troubleshooting/control/{uuid}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getDeviceConfiguration(vmanage, uuid):
    """
    Debug device bring up
    
    Parameters:
    uuid	 (string):	Device uuid
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/troubleshooting/devicebringup?uuid={uuid}"
    response = vmanage.apiCall("GET", endpoint)
    return response



def getList(vmanage, deviceId):
    """
    Get device reboot history
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/reboothistory?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getDetails(vmanage):
    """
    Get detailed reboot history list
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/reboothistory/details"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getSyncedList(vmanage, deviceId):
    """
    Get device reboot history synchronously
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/reboothistory/synced?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response



def getAllTenants(vmanage, deviceId):
    """
    Lists all the tenants on the vManage
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    deviceId	 (string):	List all tenants associated with a vSmart
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/tenant?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def createTenant(vmanage, tenantModel):
    """
    Create a new tenant in Multi-Tenant vManage
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    tenantModel:	Tenant model
    
    tenantModel Parameter example
    
    param = {
        "password": "12345",
        "tenantIdList": [
        "0f4f1c6e-47da-40c4-8517-9d1e918965d9",
        "6b7b23bf-5dba-4cca-a36c-1c3cc2254d68"
        ]
    }
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/tenant"
    response = vmanage.apiCall("POST", endpoint, tenantModel)
    return response
def createTenantAsync(vmanage, tenantModel):
    """
    Create a new tenant in Multi-Tenant vManage asynchronously
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    tenantModel:	Tenant model
    
    tenantModel Parameter example
    
    param = {
        "password": "12345",
        "tenantIdList": [
        "0f4f1c6e-47da-40c4-8517-9d1e918965d9",
        "6b7b23bf-5dba-4cca-a36c-1c3cc2254d68"
        ]
    }
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/tenant/async"
    response = vmanage.apiCall("POST", endpoint, tenantModel)
    return response
def createTenantAsyncBulk(vmanage, tenantModel):
    """
    Create multiple tenants on vManage asynchronously
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    tenantModel:	Tenant model
    
    tenantModel Parameter example
    
    param = {
        "password": "12345",
        "tenantIdList": [
        "0f4f1c6e-47da-40c4-8517-9d1e918965d9",
        "6b7b23bf-5dba-4cca-a36c-1c3cc2254d68"
        ]
    }
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/tenant/bulk/async"
    response = vmanage.apiCall("POST", endpoint, tenantModel)
    return response
def deleteTenantAsyncBulk(vmanage, tenantModel):
    """
    Delete multiple tenants on vManage asynchronously
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    tenantModel:	Tenant model
    
    tenantModel Parameter example
    
    param = {
        "password": "12345",
        "tenantIdList": [
        "0f4f1c6e-47da-40c4-8517-9d1e918965d9",
        "6b7b23bf-5dba-4cca-a36c-1c3cc2254d68"
        ]
    }
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/tenant/bulk/async"
    response = vmanage.apiCall("DELETE", endpoint, tenantModel)
    return response
def getTenantvSmartMapping(vmanage):
    """
    Retrieve mapping of tenants to vSmarts
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/tenant/vsmart"
    response = vmanage.apiCall("GET", endpoint)
    return response
def tenantvSmartMtMigrate(vmanage):
    """
    Migrate tenants from single tenant vSmarts to multi-tenant capable vSmarts
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/tenant/vsmart-mt/migrate"
    response = vmanage.apiCall("POST", endpoint)
    return response
def getTenantHostingCapacityOnvSmarts(vmanage):
    """
    Lists all the vsmarts on the vManage and its tenant hosting capacity
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/tenant/vsmart/capacity"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getTenant(vmanage, tenantId):
    """
    Get a tenant by Id
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    tenantId	 (string):	Tenant Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/tenant/{tenantId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def updateTenant(vmanage, tenantModel, tenantId):
    """
    Update a tenant in Multi-Tenant vManage
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    tenantModel:	Tenant model
	tenantId	 (string):	Tenant Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/tenant/{tenantId}"
    response = vmanage.apiCall("PUT", endpoint, tenantModel)
    return response
def deleteTenant(vmanage, tenantModel, tenantId):
    """
    Delete a tenant by Id
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    tenantModel:	Tenant model
	tenantId	 (string):	Tenant Id
    
    tenantModel Parameter example
    
    param = {
        "password": "12345",
        "tenantIdList": [
        "0f4f1c6e-47da-40c4-8517-9d1e918965d9",
        "6b7b23bf-5dba-4cca-a36c-1c3cc2254d68"
        ]
    }
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/tenant/{tenantId}/delete"
    response = vmanage.apiCall("POST", endpoint, tenantModel)
    return response
def switchTenant(vmanage, tenantId):
    """
    Switch to a specific tenant
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    tenantId	 (string):	Tenant Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/tenant/{tenantId}/switch"
    response = vmanage.apiCall("POST", endpoint)
    return response
def vSessionId(vmanage, tenantId):
    """
    Get VSessionId for a specific tenant
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    tenantId	 (string):	Tenant Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/tenant/{tenantId}/vsessionid"
    response = vmanage.apiCall("POST", endpoint)
    return response
def getAllTenantStatuses(vmanage):
    """
    List all tenant status
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/tenantstatus"
    response = vmanage.apiCall("GET", endpoint)
    return response
def forceStatusCollection(vmanage):
    """
    Force tenant status collection
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/tenantstatus/force"
    response = vmanage.apiCall("POST", endpoint)
    return response



def getAttached(vmanage, deviceId):
    """
    Get App hosting attached device from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/app-hosting/attached-devices?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getDetails(vmanage, deviceId):
    """
    Get App hosting details from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/app-hosting/details?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getGuestRoutes(vmanage, deviceId):
    """
    Get App hosting guest routes from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/app-hosting/guest-routes?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getNetworkDevices(vmanage, deviceId):
    """
    Get App hosting network interface from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/app-hosting/network-interfaces?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getNetworkUtils(vmanage, deviceId):
    """
    Get App hosting network utilization from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/app-hosting/network-utilization?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getProcesses(vmanage, deviceId):
    """
    Get App hosting processes from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/app-hosting/processes?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getStorageUtils(vmanage, deviceId):
    """
    Get App hosting storage utilization from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/app-hosting/storage-utilization?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getUtilization(vmanage, deviceId):
    """
    Get App hosting utilization from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/app-hosting/utilization?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response



def getConfig(vmanage, deviceId):
    """
    Retrieve MDP ConfigObject
    
    Parameters:
    Parameter Description
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/mdp/policies/mdpconfig/{deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response



def getBfdStats(vmanage, deviceId):
    """
    Get tunnel BFD statistics all devices
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/tunnel/bfd_statistics?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getFecStats(vmanage, deviceId):
    """
    Get tunnel fec statistics
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/tunnel/fec_statistics?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getGreKeepalives(vmanage, deviceId):
    """
    Get GRE keep alive information
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/tunnel/gre-keepalives?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getIpsecStats(vmanage, deviceId):
    """
    Get tunnel IPSec statistics all devices
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/tunnel/ipsec_statistics?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getPacketDuplicateStats(vmanage, deviceId):
    """
    Get tunnel statistics packet duplication statistics
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/tunnel/packet-duplicate?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getStats(vmanage, deviceId):
    """
    Get tunnel statistics all devices
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/tunnel/statistics?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
